# PyPanelX Project
The goal for this project it's to write a full python panel cli with tools for what it's call "Data Hoarding" or backups if you think in another ways(?)
## Tools?
Yes, tools or addons that you can write thanks to modular construction of PyPanel
## List Of addons:
- iltools: Using the powerfull [Instaloader Python Module](https://instaloader.github.io/as-module.html) i write this for a better archiving of a instagram media.

## Usage:
### From pypi:
```
pip install pypanel
```
### Build and install by yourself:
```
git clone https://github.com/jamesphoenixcode/pypanel.git
cd pypanel
pip install setuptool wheel
python setup.py sdist bdist_wheel
```
### Install in your system:
```
pip install ./dist/pypanelx-1.0.0-py3-none-any.whl
```
### Then:
```
pypanel
```
Files will be downloaded inside "pypanelMedia" in the directory where pypanel has been executed.

`thanks to coffee and weed i write this in one sunday (03/26/2023)`